=======
Credits
=======

Development Lead
----------------

* Aaron Garrett <garrett AT inspiredintelligence DOT io>

Contributors
------------

See: https://github.com/aarongarrett/inspyred/graphs/contributors
